@@ -139,8 +139,7 @@ class ImplicitSolver(SolverBase):
             inner_stepper = jit(inner_stepper)
 
         def stepper(state: FieldBase, t_start: float, t_end: float) -> float:
-            """use Euler stepping to advance `state` from `t_start` to
-            `t_end`"""
+            """use Euler stepping to advance `state` from `t_start` to `t_end`"""
             # calculate number of steps (which is at least 1)
             steps = max(1, int(np.ceil((t_end - t_start) / dt)))
             t_last, nfev = inner_stepper(state.data, t_start, steps)
