@@ -705,8 +705,8 @@ class SteadyStateTracker(TrackerBase):
                     # advance progress bar to 100%
                     self._progress_bar.n = self._pbar_offset - np.log10(self.atol)
                     try:
-                        self._progress_bar.sp(bar_style="success")
-                    except TypeError:
+                        self._progress_bar.disp(bar_style="success", check_delay=False)
+                    except (TypeError, AttributeError):
                         self._progress_bar.close()
                 raise FinishedSimulation("Reached stationary state")
 
@@ -817,8 +817,6 @@ class ConsistencyTracker(TrackerBase):
         if not np.all(np.isfinite(field.data)):
             raise StopIteration("Field was not finite")
 
-        self._last = field.data.copy()  # store data from last time step
-
 
 class MaterialConservationTracker(TrackerBase):
     """Tracking interrupting the simulation when material conservation is broken"""
